## 4.3.0 (December 1, 2022)

### New breakpoints system

Add [`break points`](https://github.com/JetBrains/kotlin-web-site-ui/blob/c1b5f8f69c692b9e4041a1b3d1685a818ecef197/src/components/breakpoints/constants.ts#L1-L9) based on different typ devices width:
  - Mobile small (**MS**)
  - Mobile medium (**MM**) 
  - Tablet small (**TS**)
  - Tablet medium (**TM**)
  - Tablet large (**TL**)
  - Desktop small (**DS**)
  - Desktop medium (**DM**)

  * `BREAKPOINTS`, `BREAKPOINTS_MAX_MEDIA` and `BREAKPOINTS_MIN_MEDIA` constants exported for inline JSX usage:
  ```jsx
    function FlowerAdaptiveImg () {
      return (
        <picture>
          <source media={BREAKPOINTS_MAX_MEDIA.MM} srcset="flowers-mobile.jpg">
          <source media={BREAKPOINTS_MIN_MEDIA.TS && BREAKPOINTS_MAX_MEDIA.TL} srcset="flowers-tablet.jpg">
          <img src="flowers-desktop.jpg" alt="Flowers">
        </picture>
      );
    }
```
  * New breakpoint [**hooks**](https://github.com/JetBrains/kotlin-web-site-ui/blob/c1b5f8f69c692b9e4041a1b3d1685a818ecef197/src/components/breakpoints/hooks.ts#L5-L31) provide adaptive browser templates:
  ```jsx
  function FlowerAdaptiveImg () {
    const isMM = useMM();
    const size = isMM ? 'small' : 'large';
    return <img src={`flowers-${size}.jpg`} alt="Flowers">;
  }
```

### New pages layout

Motivation of next layout is reduce type layouts and use fix counts of resolutions without pixel-by-pixel fluid container.

  * Providing new classes `ktl-layout`, `ktl-layout--center`, `ktl-layout--spacing` for fluid grid. More information in storybook.
  * Providing new postcss `custom media` with device type like:
  ```css
   @media (--ktl-ds) {
     // ...
   }

   @media (--ktl-mm-min) {
     // ...
   }
```
  Medias without postfix used `max-width: $size`, medias with `-min` postfix used `min-width: $size`.
  
  For use medias in your project it should provide [postcss-custom-media](https://github.com/csstools/postcss-custom-media):
  ```js
  require("@webteam/postcss-preset")({
    customMedia: [
        // ...
        '@jetbrains/kotlin-web-site-ui/out/components/breakpoints/media.pcss'
    ],
    // ...
  })
```